"use strict";
/*
 * Copyright (c) 2021, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.deepFreeze = void 0;
/**
 * Deeply freezes an object, making the entire thing immutable.
 *
 * @param object - Object to deep freeze
 * @returns A deeply frozen version of the object
 */
function deepFreeze(object) {
    const propNames = Object.getOwnPropertyNames(object);
    for (const name of propNames) {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
        const val = object[name];
        if (val && typeof val === 'object') {
            deepFreeze(val);
        }
    }
    return Object.freeze(object);
}
exports.deepFreeze = deepFreeze;
//# sourceMappingURL=collections.js.map